#
# spec file for package oracleasm
#
# Copyright (c) 2023 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo
# needssslcertforbuild

# set buildrt 1 (old 0)
%ifarch x86_64
# Enable RT builds for SLE-15-SP6
%define buildrt 1
%endif

Name:           oracleasm
Url:            https://github.com/oracle/linux-uek
Version:        2.0.8
Release:        150600.16.10.1
Summary:        Kernel driver backing the Generic Linux ASM Library
# from https://github.com/oracle/linux-uek, branch uek6/u3.
License:        GPL-2.0
Group:          System/Kernel
Source0:        %{name}-%{version}-uek6-u3.tar.xz
Source1:        Module.supported
Source2:        oracleasm.preamble
Patch1:         oracleasm-rename-BIO_MAX_PAGES-to-BIO_MAX_VECS.patch
Patch2:         oracleasm-fix-use-of-BDI_CAP_-values-no-longer-present.patch
Patch3:         oracleasm-convert-blkdev_get-to-blkdev_get_by_dev.patch
Patch4:         oracleasm-use-timespec64.patch
Patch5:         oracleasm-handle-compat_timespec.patch
Patch6:         oracleasm-add-namespace-arg-where-needed.patch
Patch7:         oracleasm-add-needed-include.patch
Patch8:	        oracleasm-asm_bio_map_user_iov-and-asm_bio_unmap-update-for-5.15+-kernel.patch
Patch9:         oracleasm-there-is-no-BIP_USER_MAPPED-flag.patch
patch10:        oracleasm-work-with-6.4-kernel.patch
patch11:        oracleasm-work-with-6.5-kernel.patch
Patch12:        oracleasm-fix-sle-15-sp5-issues.patch
Patch13:        oracleasm-handle-FMODE_EXCL-removal.patch
Patch14:        oracleasm-handle-blkdev_put-holder-change.patch
Patch15:        oracleasm-Fix-PI-when-use_logical_block_size-is-set.patch
Patch16:        oracleasm-fix-memory-reclaimation-not-working.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       oracleasm-kmp
BuildRequires:  kernel-syms
BuildRequires:  module-init-tools
%if 0%{?buildrt}
BuildRequires:  kernel-syms-rt
%endif
ExcludeArch:    %ix86 s390
%suse_kernel_module_package -n %{name} -p %{S:2} kdump um

%description
This package provides kernel module for ASMLib. You need oracleasmlib
and oracleasm-support package to use this.



Authors:
--------
    Joel Becker <joel.becker@oracle.com>

%package KMP
Summary:        Kernel driver backing the Generic Linux ASM Library
Group:          System/Kernel

%description KMP
This package provides KMP modules for oracleasm. You need oracleasmlib
and oracleasm-support package to use this.



%prep
%define subdir drivers/block/oracleasm
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
cp %{_sourcedir}/Module.supported %{subdir}/Module.supported
set -- *
mkdir source
mv "$@" source/
ln -s source/* .
mkdir obj

%build
export CONFIG_ORACLEASM=m
for flavor in %{flavors_to_build}; do
	rm -rf obj/$flavor
	cp -r source obj/$flavor
	make -k %{?_smp_mflags} -C /usr/src/linux-obj/%{_target_cpu}/$flavor \
		M=$PWD/obj/$flavor/%{subdir} \
		KCPPFLAGS="-I$PWD/obj/$flavor/include" \
		modules
done

%install
export CONFIG_ORACLEASM=m
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko /lib/firmware"
for flavor in %{flavors_to_build}; do
	make -C /usr/src/linux-obj/%{_target_cpu}/$flavor \
		modules_install M=$PWD/obj/$flavor/%{subdir}
done

%changelog
* Wed May 14 2025 brahmajit.das@suse.com
- Fix oracleasm memory reclaimation not working (bsc#1235682)
  * oracleasm-fix-memory-reclaimation-not-working.patch
* Thu Mar 13 2025 brahmajit.das@suse.com
- Fix PI when use_logical_block_size is set
  * oracleasm-Fix-PI-when-use_logical_block_size-is-set.patch
* Wed Mar 20 2024 jcheung@suse.com
- Enable kmp-rt for SLERT15 SP6
* Thu Jan 25 2024 lduncan@suse.com
- Handle kernel change that remove FMODE_EXCL by removing
  it's use (bsc#1218972), adding:
  * oracleasm-handle-FMODE_EXCL-removal.patch
  * oracleasm-handle-blkdev_put-holder-change.patch
* Mon Nov 27 2023 lduncan@suse.com
- Fix issues with block layer changes (such as bio_kmalloc()) and
  the KMP (bsc#1215781), adding:
  * oracleasm-fix-sle-15-sp5-issues.patch
* Tue Oct 31 2023 lduncan@suse.com
- Enable KMP compilation with the 6.5 linux kernel (bsc#1214832),
  adding:
  * oracleasm-work-with-6.5-kernel.patch
* Wed Sep  6 2023 lduncan@suse.com
- Enable KMP compilation with 6.4 linux kernel (bsc#1214832),
  adding:
  * oracleasm-work-with-6.4-kernel.patch
  Also, "buildrt" was disabled, since that is still at 5.14.
* Tue Jan 24 2023 jcheung@suse.com
- Enable kmp-rt for SLERT15 SP5
* Thu Jan 12 2023 lduncan@suse.com
- Updating to latest upsstream, from Oracle, in branch
  uek6/u3, thus updating the tarball from oracleasm-2.0.8.tar.xz
  to oracleasm-2.0.8-uek6-u3.tar.xz, and obviating the need
  for some patches (now removed):
  * 0001-oracleasm-Convert-block-layer-status-to-errno.patch
  * 0001-oracleasm-Kernel-interface-changes-for-4.12.patch
  * 0002-oracleasm-Kernel-interface-tweaks-for-4.14.patch
  * 0003-oracleasm-Kernel-interface-tweaks-for-SLE15-SP1.patch
  * 0004-oracleasm-Kernel-interface-tweaks-for-5.3.patch
  * oracleasm-add-enxio-handling.patch
  * oracleasm-fix-bio_map_user_iov-usage.patch
  * oracleasm-fix-blk_get_request-removal.patch
  * oracleasm-fix-memory-leak.patch
  * oracleasm-implement-support-for-query-handle-operation.patch
  * oracleasm-tracing-update.patch
  * oracleasm-work-with-newer-5.15-kernel.patch
  * oracleasm_Fix_use_after_free_for_request_processing_timer.patch
  Also, added a patch from Oracle meant to address current issues
  in bsc#1202844 and bsc#1205499, adding:
  * oracleasm-asm_bio_map_user_iov-and-asm_bio_unmap-update-for-5.15+-kernel.patch
  Lastly, added one more patch that makes their driver compile:
  * oracleasm-there-is-no-BIP_USER_MAPPED-flag.patch
* Wed Dec  7 2022 lduncan@suse.com
- Add patch to handle removal of the block subsystem function
  blk_get_request (bsc#1205499), adding:
  * oracleasm-fix-blk_get_request-removal.patch
* Fri Nov 18 2022 lduncan@suse.com
- Added new patch to ensure that blk-integrity.h is included
  where needed (bsc#1205499), for newer kernel:
  * oracleasm-add-needed-include.patch
* Wed Sep 22 2021 sweiberg@suse.com
- setting buildrt to 0, as we don't ship a real time kernel with
  SLE 15 SP4. The real time kernel is part of the SLE RT 15 SP4
  product and contains a fork of oracleasm anyways.
* Fri Sep 17 2021 lduncan@suse.com
- Updated to work with 5.14 kernel, adding patches (bsc#1190360):
  * oracleasm-rename-BIO_MAX_PAGES-to-BIO_MAX_VECS.patch
  * oracleasm-fix-use-of-BDI_CAP_-values-no-longer-present.patch
  * oracleasm-convert-blkdev_get-to-blkdev_get_by_dev.patch
  * oracleasm-fix-bio_map_user_iov-usage.patch
  * oracleasm-use-timespec64.patch
  * oracleasm-handle-compat_timespec.patch
  * oracleasm-add-namespace-arg-where-needed.patch
  Also added oracleasm.preamble, as suggested by rpmlint.
* Tue Aug  3 2021 lduncan@suse.com
- Added 4 upstream commits/patches, as requested by support
  (bsc#1189119):
  * oracleasm-fix-memory-leak.patch
  * oracleasm-tracing-update.patch
  * oracleasm-add-enxio-handling.patch
  * oracleasm-implement-support-for-query-handle-operation.patch
* Tue Nov 24 2020 aksingh@suse.com
- bsc#1177231 - Changed timer_setup(&to->timer, timeout_func, 0);
  0004-oracleasm-Kernel-interface-tweaks-for-5.3.patch
* Tue Jun 30 2020 aksingh@suse.com
- Fix ASMLIB sends the message ASM_LOCAL_ERROR (bsc#1171818)
  Add 0001-oracleasm-Convert-block-layer-status-to-errno.patch
* Wed Aug 14 2019 msuchanek@suse.de
- Fix use after free for request processing timer (bsc#1145675).
  Add oracleasm_Fix_use_after_free_for_request_processing_timer.patch
* Thu Aug  8 2019 msuchanek@suse.de
- Fix build error with kernel 5.3 (bsc#1144700).
  Add 0004-oracleasm-Kernel-interface-tweaks-for-5.3.patch
* Thu Dec 13 2018 msuchanek@suse.de
- Fix error: storage size of 'iter' isn't known (bsc#1119403).
  Add 0003-oracleasm-Kernel-interface-tweaks-for-SLE15-SP1.patch
* Fri Sep 14 2018 jcheung@suse.com
- Enable kmp-rt for SLERT15 SP1
* Fri Jan  5 2018 aksingh@suse.com
- bsc#1074655: Reverting to original Oracle patch as SUSE changes not required
  Add 0001-oracleasm-Kernel-interface-changes-for-4.12.patch
  Add 0002-oracleasm-Kernel-interface-tweaks-for-4.14.patch
  Drop oracleasm-Kernel-interface-changes-for-4.12.patch
* Fri Nov 17 2017 aksingh@suse.com
-  Updated code for SLES15 Kernel (bsc#1053298, bsc#1093128)
  Add oracleasm-Kernel-interface-changes-for-4.12.patch
  Drop patch 0001-WARNING-lib-modules-4.4.73-5-default-updates-oracle.patch
  Drop patch oracleasm-Fix-submit_bio-API-change.patch
* Fri Sep 22 2017 aksingh@suse.com
- fix for unknown symbol bio_unmap_user (bsc#1059062)
  0001-WARNING-lib-modules-4.4.73-5-default-updates-oracle.patch
* Mon Mar 13 2017 mmarek@suse.cz
- Fix build with the SLE12-SP3 kernel (bsc#1026064).
* Wed Feb 17 2016 mmarek@suse.cz
- Update to build against the 4.4 kernel (bsc#962720).
* Wed Oct  7 2015 lpechacek@suse.com
- Enable RT KMP build (bsc#948840)
* Tue Jun 23 2015 ro@suse.de
- add excludearch for i586 and s390 (no binary kernels on 32bit
  sibling architectures) (bnc#935750)
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Mar 12 2014 mmarek@suse.cz
- Enable parallel build.
* Fri Feb  7 2014 lchiquitto@suse.de
- Add Module.supported to package's sources.
* Tue Feb  4 2014 mmarek@suse.cz
- Update to version 2.0.8 (bnc#858282).
* Mon May 20 2013 rgoldwyn@suse.com
- introduce-module-parameter-for-block-size-selection.patch  (bnc#807812)
* Thu Mar 21 2013 rgoldwyn@suse.com
- Ensure-full-IOC-buffer-can-be-mapped.patch (bnc#786189)
* Mon Feb 11 2013 mmarek@suse.cz
- Set $BRP_PESIGN_FILES in the %%install section so that modules
  are signed in the buildservice (fate#314552).
* Wed Jan 30 2013 mmarek@suse.cz
- Add # needssslcertforbuild to the specfile, to make the UEFI
  signing certificate available during build (fate#314511, fate#314552).
* Wed Jul 18 2012 mmarek@suse.cz
- Fix slab error during rmmod (bnc#769971)
* Fri Sep  2 2011 mmarek@suse.cz
- Update to current git and fix build with 3.0.
* Mon Jul 18 2011 mmarek@novell.com
- Fix build with the SP2 kernel (bnc#706420).
* Fri Nov 13 2009 mmarek@suse.cz
- update to current git to fix build with newer kernel.
* Sat Feb 21 2009 agruen@suse.de
- Remove the dependency on kernel-source-rt and kernel-syms-rt:
  those -rt packages will not ship in their current versions.
* Wed Jan 14 2009 ro@suse.de
- remove "." from end of summary
* Tue Jan 13 2009 dgollub@suse.de
- Add kernel-syms-rt to build requires to build SLERT KMPs
* Mon Oct 13 2008 andavis@novell.com
- Removed extraneous files mistakenly left in source tarball.
  (No functional changes).
* Wed Sep 10 2008 andavis@novell.com
- FATE 304969
- Build SUSE KMP
- Patch for 2.6.27 kernels to remove ioctl32.h dependency
